==> munipack_0.5.10.orig.tar.gz: munipack-0.5.10/lib/mfitsio.cpp <==
/* 

  C++ versions of soubroutines in fitsio.f95

  Copyright © 2012 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  
  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.


*/

#include "mfitsio.h"
#include <string>
#include <vector>
#include <fitsio.h>
#include <stdio.h>

using namespace std;

int fitscopy(const string& ifile, const string& ofile)
{
  fitsfile *fin,*fout;
  int status;

  status = 0;
  fits_open_file(&fin,ifile.c_str(),READONLY,&status);
  fits_create_file(&fout,ofile.c_str(),&status);
  fits_copy_file(fin,fout,1,1,1,&status);
  fits_close_file(fin,&status);
  fits_close_file(fout,&status);
  fits_report_error(stderr,status);
  return status;
}


int fitsbackup(const string& file, const string& backup, bool rem)
{
  int ret = 1;

  if( backup != "" ) {
    remove(backup.c_str());
    ret = fitscopy(file,backup);
  }

  if( rem )
    remove(file.c_str());

  return ret;
}

int fitsback(const string& file, const string& backup, const string& output,
	     bool rem, string& outname)
{
  int ret = 1;

  if( output != "" ) {
    if( backup != "" )
      ret = fitsbackup(output,backup,rem);
    outname = output;
  }
  else {
    if( backup != "" )
      ret = fitsbackup(file,backup,rem);
    outname = file;
  }

  return ret;
}

==> munipack_0.6.1.orig.tar.gz: munipack-0.6.1/lib/mfitsio.cpp <==
/*

  C++ versions of soubroutines in fitsio.f95

  Copyright © 2012, 2018 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.


*/

#include "mfitsio.h"
#include <string>
#include <fitsio.h>
#include <iostream>
#include <fstream>
#include <sstream>

using namespace std;

/*
struct {
  fitsfile *fptr;
  string filename, scratch, output;
} FITSFILE;

static FITSFILE fitsfiles[50];
*/

int mfitsio_copy(const string& ifile, const string& ofile)
{
  fitsfile *fin,*fout;
  int status;

  status = 0;
  fits_open_file(&fin,ifile.c_str(),READONLY,&status);
  fits_create_file(&fout,ofile.c_str(),&status);
  fits_copy_file(fin,fout,1,1,1,&status);
  fits_close_file(fin,&status);
  fits_close_file(fout,&status);
  fits_report_error(stderr,status);
  return status;
}

int mfitsio_unlink(const string& filename)
{
  fitsfile *f;
  int status = 0;

  fits_open_file(&f,filename.c_str(),READWRITE,&status);
  fits_delete_file(f,&status);
  fits_report_error(stderr,status);
  return status;
}
